MilestoneMixin mixin

Superclass constraints
Implemented types
Mixin applications
Available extensions

Properties

assistedTask ITaskFactForMModel?
Property getter and setter for assistedTask:
getter/setter pairinherited
author → MKey?
no setterinherited
contactKey ↔ MKey?
getter/setter pairoverride
contactKeys List<MKey>?
Property getter and setter for contactKeys:
getter/setter pairinherited
creator ↔ IReliveItContact?
Property getter and setter for creator:
getter/setter pairinherited
dateCreated DateTime
Property getter and setter for dateCreated:
getter/setter pairinherited
details String?
Property getter and setter for details:
getter/setter pairinherited
factSchema ↔ IFactSchema
getter/setter pairinherited
factSchemaOrNull → IFactSchema?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
no setterinherited
isAttribute bool
no setterinherited
isHistory bool
no setterinherited
isPending bool
no setterinherited
labeled LabeledFact?

Available on IFact, provided by the FactLabelRemindableExt extension

no setter
location ↔ IPhysicalLocation?
Property getter and setter for location:
getter/setter pairinherited
mfields Set<String>
no setterinherited
milestone String?
Property getter and setter for milestone:
getter/setter pairinherited
milestoneDate ↔ FlexiDate?
Property getter and setter for milestoneDate:
getter/setter pairinherited
mkey → MKey?
no setterinherited
mtype → MSchemaRef
no setterinherited
photos List<IImageContent>?
Property getter and setter for photos:
getter/setter pairinherited
remindable RemindableFact?

Available on IFact, provided by the FactLabelRemindableExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTimestamp bool
no setterinherited
smartNoteDate DateTime?
no setterinherited
videos List<IVideoContent>?
Property getter and setter for videos:
getter/setter pairinherited

Methods

clone() IMilestone
inherited
getByPath<T>(JsonPath path) → T
inherited
getDate(IFactMetaDate metaDate, Location location) → TZDateTime?
inherited
getFlexiDate(IFactMetaDate metaDate) → FlexiDate?
inherited
initialize(MKey targetKey, MKey agentKey) → void
override
involves(MKey contactId) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setByPath<T>(JsonPath<T> path, T? value) → dynamic
inherited
shortTitle(IRef contact) String?
subtitle(IRef contact) String
override
takeFrom(dynamic source) → void
inherited
takeFromMap(Map<String, dynamic>? from, {bool copyEntries = true}) → void
Used for meta-forms in setting deep properties
inherited
title(IRef contact) String
override
toJson() → dynamic
inherited
toMap() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic key) → dynamic
inherited
operator []=(String key, dynamic value) → void
inherited